{{-- @extends('layouts.app') --}}
@extends('layouts.sidebar')



@section('content')
   <!-- Bootstrap CSS -->
   <link rel="stylesheet" href="https://cdn.jsdelivr.net/npm/daterangepicker/daterangepicker.css" />

{{-- {{$req->sucursales}} --}}
    <!-- Daterangepicker JS -->
    <script src="https://cdn.jsdelivr.net/momentjs/latest/moment.min.js"></script>
    <script src="https://cdn.jsdelivr.net/npm/daterangepicker/daterangepicker.min.js"></script>

@if (session('url'))
    <script>
        var url = "<?php echo session('url'); ?>";
        var win = window.open(url, '_blank', 'noopener,noreferrer');
        win.opener = null; // Evita que la nueva ventana tenga una referencia al objeto del navegador actual
        win.focus(); // Pone el foco en la nueva ventana
    </script>
@endif
 <!-- content -->
<div class="titulos"> 

  @unless(empty($datosDelCliente))
       <h2>Datos personales  </h2>

  @else

    <h2>Ordenes de trabajo  </h2>

    @endunless

    <hr />

</div>


<style>
  .error {
    border: 1px solid red;  /* Add a red border to indicate the error */
}
</style>

{{-- {{$datosDelCliente}} --}}

@unless(empty($datosDelCliente))


    <div class="row">

          <div class="mb-3 col-6" >
            <label for="razon_social" class="form-label">Razon social</label>
            <input type="text" required class="form-control" id="razon_social" placeholder=""  disabled   value="{{ old('sku', isset($datosDelCliente[0]->razon_social) ? $datosDelCliente[0]->razon_social : '') }}"  name="razon_social">
            @error('razon_social')
            <div class="alert alert-danger">{{ $message }}</div>
            @enderror
          </div>

          <div class="col-md m-2">
            <label for="">Rut</label>
            <input type="text" class="form-control" disabled value="{{ old('rut', isset($datosDelCliente[0]->rut) ? $datosDelCliente[0]->rut : '') }}"  name="contacto_rut"
                id="contacto_rut">
            <span id="rut_span" style="display: none"><label for=""
                    id="error_rut"></label></span>
                    <label id="l_contacto_rut" style="display: none; color: red" for="">Campo obligatorio</label>

          </div>
            <div class="mb-3  col-6">
              <label for="giro" class="form-label">Giro</label>
              <input type="text"  class="form-control" id="giro" placeholder=""  disabled value="{{ old('giro', isset($datosDelCliente[0]->giro) ? $datosDelCliente[0]->giro : '') }}" name="giro">
              @error('giro')
            <div class="alert alert-danger">{{ $message }}</div>
            @enderror


          </div>
          <div class="mb-3 col-6" >
            <label for="telefono" class="form-label">Telefono</label>
            <input type="text" required class="form-control" id="telefono" placeholder="" disabled value="{{ old('telefono', isset($datosDelCliente[0]->telefono) ? $datosDelCliente[0]->telefono : '') }}" name="telefono">
            @error('telefono')
          <div class="alert alert-danger">{{ $message }}</div>
          @enderror


          </div>
          <div class="mb-3  col-6">
            <label for="correo" class="form-label">Correo</label>
            <input type="email"  class="form-control" id="correo" placeholder=""   disabled value="{{ old('correo', isset($datosDelCliente[0]->correo) ? $datosDelCliente[0]->correo : '') }}" name="correo">
            @error('correo')
            <div class="alert alert-danger">{{ $message }}</div>
            @enderror

          </div>
          <div class="mb-3 col-6" >
            <label for="direccion" class="form-label">Direccion</label>
            <input type="text" required class="form-control" id="direccion" placeholder=""    disabled value="{{ old('direccion', isset($datosDelCliente[0]->nombre_direccion) ? $datosDelCliente[0]->nombre_direccion : '') }}" name="direccion">
            @error('direccion')
            <div class="alert alert-danger">{{ $message }}</div>
            @enderror
          </div>

          <div class="mb-3 col-6" >
            <label for="direccion" class="form-label">Región</label>
            <input type="text" required class="form-control" id="direccion" placeholder=""    disabled value="{{ old('direccion', isset($datosDelCliente[0]->des_region) ? $datosDelCliente[0]->des_region : '') }}" name="direccion">
            @error('direccion')
            <div class="alert alert-danger">{{ $message }}</div>
            @enderror
          </div>  <div class="mb-3 col-6" >
            <label for="direccion" class="form-label">Comuna</label>
            <input type="text" required class="form-control" id="direccion" placeholder=""    disabled value="{{ old('direccion', isset($datosDelCliente[0]->des_comuna) ? $datosDelCliente[0]->des_comuna : '') }}" name="direccion">
            @error('direccion')
            <div class="alert alert-danger">{{ $message }}</div>
            @enderror
          </div>
        {{-- fin del row --}}
    </div>
@endunless

@if(session('mensaje'))
    <div class="alert alert-success">
        {{ session('mensaje') }}
    </div>
@endif
 <div class="container-fluid botones-extremo " >
  
</div> 
@unless(empty($datosDelCliente))
    <div class="container-fluid botones-extremo " >
      <hr>
      <div class="d-flex justify-content-between">
         <h5>Ordenes de trabajo</h5>
        
      </div>
    </div>

@else


  @if(\App\Models\User::tipoUsuario() != "operario")

      <div class="container-fluid botones-extremo " >
        <div class="d-flex justify-content-between">
            <a href="{{ route('ot.crearsincliente') }}" class=" btn  btn-success" title="" >Nuevo</a>
          
        </div>
      </div>
  @endif

@endunless

    <div class="row">
      <form action="{{ route('filtrarOt.ot') }}" method="GET" class="row" style="margin-left: 4px">

        @csrf

        @if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin")

              <div class="col-3"> 

                <label for="">Sucursal</label>
                <select  class="form-control" name="sucursales" id="selecionar_sucursal">

                  <option value="">Seleccionar</option>
                  @if(!empty($sucursales))
                            @foreach($sucursales as $data)
                            @if(!empty($req->sucursales ))

                                @if($data->id == $req->sucursales ?? '')
                                <option selected value="{{$data->id}}" {{(old('sucursal')==$data->id)? 'selected':''}}>{{$data->descripcion}}</option>
                                @else
                                <option  value="{{$data->id}}" {{(old('sucursal')==$data->id)? 'selected':''}}>{{$data->descripcion}}</option>

                                @endif
                                @else
                                <option  value="{{$data->id}}" {{(old('sucursal')==$data->id)? 'selected':''}}>{{$data->descripcion}}</option>

                                @endif



                            @endforeach
                            @endif
          
                </select>
              </div>
      @endif

    <!-- FECHA -->
    <div class="form-group col-md-3">
      <label for="">Fechas</label>

          <!-- <label for="dateRangeSelect">Rango de Fecha</label> -->
          <input style="cursor: pointer" type="text" class="form-control" id="customDateRange" name="customDateRange"
          value="<?php echo htmlspecialchars($_GET['customDateRange'] ?? ''); ?>">
   
          <input type="date" hidden class="form-control"  id="fecha_inicio" name="fecha_inicio">
          <input type="date" hidden class="form-control"  id="fecha_fin" name="fecha_fin">

      </div>


      {{-- ESTADOS --}}
      <div class="form-group col-md-3">
        <label for="">Estados</label>
  
        <select  class="form-control" name="estados" id="estados">

          <option value="">Seleccionar</option>
          @if(!empty($estados_ot))
                    @foreach($estados_ot as $data)
                    @if(!empty($req->estados ))

                        @if($data->id == $req->estados ?? '')
                        <option selected value="{{$data->id}}" {{(old('estados')==$data->id)? 'selected':''}}>{{$data->descripcion}}</option>
                        @else
                        <option  value="{{$data->id}}" {{(old('estados')==$data->id)? 'selected':''}}>{{$data->descripcion}}</option>

                        @endif
                        @else
                        <option  value="{{$data->id}}" {{(old('estados')==$data->id)? 'selected':''}}>{{$data->descripcion}}</option>

                        @endif



                    @endforeach
                    @endif
            </select>
  
        </div>
                {{-- <div class="col-3"> 

            <label for="">Fecha Inicio</label>
            <input type="date" class="form-control" value="{{ isset($req) ? $req->fecha_inicio : '' }}" id="fecha_inicio" name="fecha_inicio">

          </div> 
          
          <div class="col-3"> 

            <label for="">Fecha fin</label>
            <input type="date" class="form-control" value="{{ isset($req) ? $req->fecha_fin : '' }}" id="fecha_fin" name="fecha_fin">

          </div> --}}
          
          
          
          
          <div class="col-3"> 
        <br>
        <button type="submit" class="btn btn-success">Filtrar</button> 
      <button type="button" class="btn btn-primary" onclick="exportardata()" >Exportar</button>
      <button style="color: white" type="button" class="btn btn-info" onclick="imprimirData()" >Imprimir</button>

      </form>
      
  </div>
</div>




 <div class="container-fluid table-responsive">
    <div class="row">
        <div class="col bttn-buscar">
            <input type="text" class="form-control" id="buscarData" placeholder="Buscar">
        </div>
    </div><br>
   <div style="text-align: right">
    {{-- <a  title="Exportar" href="{{ route('exportarOt') }}" class="nav-link py-3 px-2" title="" data-bs-toggle="tooltip" data-bs-placement="right" data-bs-original-title="Home"> --}}

      {{-- <span class="material-symbols-outlined">
        description
        </span>
      </a> --}}
   </div>
    {{--INICIO TABLA --}}
   <div  style=" display: none  ;text-align: right; cursor: pointer; margin-right: 15px;">
    <a >
      <span class="material-symbols-outlined" onclick="imprimirData()" >print</span>
  </a>
   </div>
    <div class="table-responsive mb-5">
        <table class="table table-striped table-hover" id="mitable">
          <thead class="color-head">
            {{-- id	nombre_servicio	descripcion	sku	precio_neto	iva	eliminado	estado	categorias_id --}}
            <tr>
              <th class="th-subhead border-th">Id</th>

              @if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin")
                <th class="th-subhead border-th">Sucursal</th>
              @endif

              @if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria")
              <th class="th-subhead border-th">Contacto</th>
              <th class="th-subhead border-th" style="width: 100px;">Rut</th>
              <th class="th-subhead border-th" style="width: 100px;">Motor</th>

              <th class="th-subhead border-th">Operario encargado</th>
              <th class="th-subhead border-th"  style="width: 150px;" >Total</th>
              @endif


              @if(\App\Models\User::tipoUsuario() == "operario" )
                    <th class="th-subhead border-th separador-v">Marca</th>
                    <th class="th-subhead border-th separador-v">Modelo</th>
                    <th class="th-subhead border-th separador-v">Motor</th>
                    <th class="th-subhead border-th separador-v">Año</th>
                    <th class="th-subhead border-th separador-v">Combustible</th>
              @endif

              <th class="th-subhead border-th separador-v">Fecha ingreso</th>
              <th class="th-subhead border-th">Fecha entrega</th>
              <th class="th-subhead border-th separador-v">Estado</th>

              <th class="th-subhead border-th">Acción</th>
              {{-- <th class="th-subhead border-th">Comuna</th> --}}
              <th class="th-subhead border-th"></th>
            </tr>
          </thead>
          
          <tbody id="tableOt"></tbody>
          <tbody id="tableOtGeneral">

            <tr>
                {{-- <td class="td-val">a</td> --}}
                
                
              </tr>
              {{-- {{$usuarios}} --}}
              {{-- [{"id_usuariio":2
              "id":1
              "nombre":"ariel"
              "apellido":"alejandro"
              "rut":"1-9"
              "fecha_nacimiento":"marzo"
              "direccion":"talca"
              "telefono":"53425865"
              "nacionalidades_id":1
              "direcciones_id":1
              "des_comuna":"Arica"
              "des_region":"Arica y Parinacota"}] --}}

              
            @if(!empty($ordenesdetrabajo))
             @foreach ($ordenesdetrabajo as $los_datos)

              <tr>


                {{-- <td>

                  <a href="{{ route('imprimirot', ['idOT' => $los_datos->id]) }}" target="_blank">
                    <span class="material-symbols-outlined">print</span>
                  </a>
                </td> --}}

                <td class="td-val">{{$los_datos->numero_ot}}</td>
              @if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin")
                <td class="td-val">{{$los_datos->nombre_sucursal}}</td>
              @endif

              @if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria")
                    <td class="td-val">{{$los_datos->razon_social}}</td>
                    <td class="td-val">{{$los_datos->rut}}</td>

                    <td class="td-val">
                      {{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->marca}}
                      {{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->modelo}}
                      {{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->motor}}
                      {{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->ano}}
                      {{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->nombrecombustible}}


                    </td>

                    <td class="td-val">{{$los_datos->nombre_completo}}</td>

              @endif


              @if(\App\Models\User::tipoUsuario() == "operario" )
              <td class="td-val">{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->marca}}</td>
              <td class="td-val">{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->modelo}}</td>
              <td class="td-val">{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->motor}}</td>
              <td class="td-val">{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->ano}}</td>
              <td class="td-val">{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id)[0]->nombrecombustible}}</td>

              @endif

              @if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria")

              <td class="td-val">$
              {{number_format($los_datos->total_con_descuentos, 0, ',', '.')}}
              </td>
              @endif

                <td class="td-val">
                  
                  {{Carbon\Carbon::createFromDate($los_datos->fecha_ingreso?? '')->format('d-m-Y')}}
                  {{-- {{$los_datos->fecha_ingreso}} --}}
                
                </td>
                <td class="td-val">
                  {{-- {{$los_datos->fecha_entrega}} --}}

                  @if($los_datos->fecha_entrega != "")
                  {{Carbon\Carbon::createFromDate($los_datos->fecha_entrega ?? '')->format('d-m-Y')}}
                  @endif
                
                </td>
                {{-- <td class="td-val">{{$los_datos->giro}}</td> --}}
                <td class="td-val">{{$los_datos->descripcionestado}}</td>


                @if( $los_datos->descripcionestado== "PRESUPUESTO") 

                <td class="td-val">
                  <a href="{{ route('ordendetrabajo.show', ['id' => $los_datos->id]) }}" >
                    <span class="material-symbols-outlined" style="cursor:pointer" title="Completa OT">
                      visibility
                      </span>
                  </a>
                  <span class="material-symbols-outlined" style="cursor:pointer" title="Historial OT"  onclick="abrirModal({{$los_datos->numero_ot}})" >
                    manage_search
                    </span>
                </td>

                @else
                          <td class="td-val">

                            
                            @if($los_datos->descripcionestado == "FACTURADA" || $los_datos->descripcionestado == "CANCELADA" )

                                    @if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin")

                                          <a href="{{ route('ordendetrabajo.showhistorial', ['id' => $los_datos->id]) }}" >
                                            <span class="material-symbols-outlined">
                                              visibility
                                              </span>
                                          </a>

                                          
                                    @endif
                            @else
                            <a href="{{ route('ordendetrabajo.show', ['id' => $los_datos->id]) }}" >
                              <span class="material-symbols-outlined" style="cursor:pointer" title="Completa OT">
                                visibility
                                </span>
                            </a>
                            
                           
                            @endif

                            


                            @if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria")

                                    <a>
                                      {{-- <span class="material-symbols-outlined" style="cursor:pointer"  title="Eliminar">
                                        delete
                                        </span> --}}
                                      </a>


                                      @if($los_datos->descripcionestado != "FACTURADA"  )

                                        <a href="{{ route('ordendetrabajo.editar', ['id' => $los_datos->id]) }}" >
                                            <span class="material-symbols-outlined" style="cursor:pointer" title="Editar">
                                              edit
                                              </span>
                                        </a>
                                        @else

                                        
                                       @endif 

                                      <span class="material-symbols-outlined" style="cursor:pointer" title="Historial OT"  onclick="abrirModal({{$los_datos->numero_ot}})" >
                                      manage_search
                                      </span>

                                      {{-- Modal para abonos --}}
                                      <span class="material-symbols-outlined" style="cursor:pointer" title="Abonos" onclick="abrirModalAbonos({{$los_datos->numero_ot}},{{$los_datos->id}})">
                                      paid
                                      </span>

                                @endif
                          </td>

                      @endif
                      <td>

                        @if($los_datos->descripcionestado ==  "RECEPCIONADA"  )
                        <a href="{{ route('ordendetrabajo.iniciarget', ['id' => $los_datos->id]) }}" class="material-symbols-outlined" style="cursor:pointer" title="Iniciar OT" onclick="return confirm('¿Estás seguro de que deseas iniciar esta OT : {{$los_datos->numero_ot}} ?')">
                          play_arrow
                      </a>

                        @elseif($los_datos->descripcionestado ==  "INICIADA"  )
                       
                        <a href="{{ route('ordendetrabajo.finalizarget', ['id' => $los_datos->id]) }}" class="material-symbols-outlined" style="cursor:pointer" title="Finalizar OT" onclick="return confirm('¿Estás seguro de que deseas finalizar esta OT: {{$los_datos->numero_ot}}?')">
                          stop_circle
                      </a>
                        {{-- <span class="material-symbols-outlined" style="cursor:pointer" title="Finalizar OT"   >
                          
                          </span> --}}
                        
                        @else

                        @endif

                      </td>
                       {{-- <td class="td-val">{{$los_datos->des_comuna}}</td> --}}

                
                
              </tr>
            @endforeach 

            @endif
          </tbody>
        </table>
        {{-- {{ $ordenesdetrabajo->links('pagination::bootstrap-4') }}
         --}}
         {{ $ordenesdetrabajo->appends(request()->query())->links('pagination::bootstrap-4') }}

      </div>
      

    {{-- FIN TABLA --}}

</div>

 <!-- Modal Tecnico -->
 <div class="modal" id="modalHistorial">
  <div class="modal-dialog"> 
      <div class="modal-content">

          <!-- Modal Header -->
          <div class="modal-header">
              <h4 class="modal-title">Historial</h4>
              <button type="button" class="btn-close" onclick="cerrarModal()"></button>


          </div>

          <!-- Modal body -->
          <div class="modal-body">

            <table class="table table-hover">
              <thead class="bg-light">
                  {{-- <th scope="col">#</th> --}}
                  <th scope="col">#</th>

                  <th scope="col">Fecha Ingresada</th>
                  <th scope="col">Ver</th>
                  <th scope="col">Pdf</th>



              </thead>
              {{-- {{$servicios_ordenes}} --}}
              <tbody id="tabla_servicios_selecionados">

                  

              </tbody>

          </table>  
                </div>
      </div>
  </div>




</div>

   <!-- Modal historial abonos -->
   <div class="modal" id="modalHistorialAbonos">
    <div class="modal-dialog"> 
        <div class="modal-content">
  
            <!-- Modal Header -->
            <div class="modal-header">
                <h4 class="modal-title">Historial</h4>
                <button type="button" class="btn-close" onclick="cerrarModalAbonos()"></button>
  
  
            </div>
  
            <!-- Modal body -->
            <div class="modal-body">

              <div class="container" >

                <div class="row">

                  <div class="col-4">
                    <label for="">Medio de pago</label>
                    <select name="" class="form-control" id="mediosPagosSelect">
                        <option value="">SELECCIONAR</option>
                        @if (!empty($medios_pagos))
                            @foreach ($medios_pagos as $data)
                                <option value="{{ $data->id }}"
                                    {{ old('modopago') == $data->id ? 'selected' : '' }}>{{strtoupper($data->descripcion) }}
                                    </option>
                            @endforeach
                        @endif
                    </select>
                  </div>
                  <div class="col-4">
                    <label for="">Monto</label>

                    <input type="text" class="form-control" oninput="permitirSoloNumeros(this)" id="montoparaabonar"> 
                  </div>
                  <div class="col-4 mt-4" >
                    <input type="button" class="btn btn-success" onclick="agregarabono()"  value="Agregar">
                  </div>
                </div>

                <div class="row mt-5">

                  <label for="ltotaladeudado" id="ltotaladeudado" style="display: inline; margin-left: 5px;"></label>

                  <table class="table table-hover">
                    <thead class="bg-light">
                        {{-- <th scope="col">#</th> --}}
      
                        <th scope="col">Fecha Ingresada</th>
                        <th scope="col">Metodo pago</th>
                        <th scope="col">Total</th>

      
      
                    </thead>
                    {{-- {{$servicios_ordenes}} --}}
                    <tbody id="table_historia_abonos">
      
                        
      
                    </tbody>
      
                </table>  
                </div>

              </div>
  
            
            </div>
        </div>
    </div>
  </div>
<script>

var numeroDelaOtGlobal = "";
var idOtGlobal = "";
var totalAdeudadoGlobal = "";



function imprimirData(){


// VALIDAR OTRO TIPO FECHA

// if($("#fecha_inicio").val() == "" || $("#fecha_fin").val() == ""){
//   response = false;
// }else{
//   response = validarDiferenciaAno("#fecha_inicio","#fecha_fin");

// }
response = false;

// alert(response);
        if(response == true){
            //mayor a un años
            
        }else{

        console.log("hola");
        var parametro1 = $("#fecha_inicio").val();
                    var parametro2 = $("#fecha_fin").val();
                    var parametro3 = $("#selecionar_sucursal").val();
                    var parametro4 = $("#estados").val();

                    var urlConParametros = '/imprimir/ordenesdetrabajo?fecha_inicio=' + encodeURIComponent(parametro1)
                    + '&fecha_fin=' + encodeURIComponent(parametro2)+ '&sucursal=' + encodeURIComponent(parametro3)+ '&estados=' + encodeURIComponent(parametro4);

                    // Abrir la nueva ventana o pestaña con la URL construida
                    window.open(urlConParametros, '_blank');

          }

}


function exportardata(){


// if($("#fecha_inicio").val() == "" || $("#fecha_fin").val() == ""){
//   response = false;
// }else{
//   response = validarDiferenciaAno("#fecha_inicio","#fecha_fin");

// }

response = false;
        if(response == true){
            //mayor a un años
            
        }else{

            var parametro1 = $("#fecha_inicio").val();
            var parametro2 = $("#fecha_fin").val();
            var parametro3 = $("#selecionar_sucursal").val();
            var parametro4 = $("#estados").val();

            var urlConParametros = '/exportar/ordenesdetrabajo?fecha_inicio=' + encodeURIComponent(parametro1)
             + '&fecha_fin=' + encodeURIComponent(parametro2)+ '&sucursal=' + encodeURIComponent(parametro3)+ '&estados=' + encodeURIComponent(parametro4);

            // Abrir la nueva ventana o pestaña con la URL construida
            window.open(urlConParametros, '_blank');

        }

// console.log(response);


    }

function agregarabono(){

  mediosPagosSelect = $("#mediosPagosSelect").val();
  montoparaabonar = $("#montoparaabonar").val();


    // Check if any of the values is null or empty
    if (!mediosPagosSelect || !montoparaabonar) {
        // Add a red border to the input fields
        if (!mediosPagosSelect) {
            $("#mediosPagosSelect").addClass("error");
        }
        if (!montoparaabonar) {
            $("#montoparaabonar").addClass("error");
        }

        // alert('Please fill in all required fields.');
        return; // Exit the function if validation fails
    }

    if(montoparaabonar > totalAdeudadoGlobal){
      return;
    }
    // Remove the red border if validation passes
    $("#mediosPagosSelect").removeClass("error");
    $("#montoparaabonar").removeClass("error");


  $.ajax({
               
               headers: {
                   'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
               },
               type: 'POST',
               url: "{{ route('ordendetrabajo.addabono') }}",
               data: {
                   'mediosPagosSelect': mediosPagosSelect,
                   'montoparaabonar': montoparaabonar,
                   'numeroDelaOtGlobal': numeroDelaOtGlobal,
                   'idOtGlobal': idOtGlobal,



                   
                  
               },
               success: function(data) {
                                   var totalabonos = 0;

               $('#modalHistorialAbonos').show();
                   console.log(data);
                   $('#table_historia_abonos').empty();

                   $.each(data.pagos, function(index, objeto) {




                  var tr = "<tr>";
                //          // tr += "<td>" + objeto.id + "</td>";
                        tr += "<td>" + (formatearFecha(objeto.fecha) || '') + "</td>";
                        tr += "<td>" + (objeto.descripcion.toUpperCase() || '') + "</td>";
                        tr += "<td>" + "$"+(format_js(objeto.total) || '') + "</td>";

                  
                        
                        tr += "</tr>";

                        totalabonos = totalabonos+ objeto.total;

                         $('#table_historia_abonos').append(tr);



                        });
                        var trt = "<tr>";
                          trt += "<td></td>";
                          trt += "<td></td>";
                          trt += "<td >" +"$"+ (format_js(totalabonos) || '') + "</td>";
                          trt += "</tr>";
                        $('#table_historia_abonos').append(trt);
                        $("#ltotaladeudado").css("display", "inline").text("Total adeudado: $"+format_js(data.adeudado));
                        totalAdeudadoGlobal  = data.adeudado;

                        
                },
                error: function(xhr, status) {
                   alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
               }
           });

}

function abrirModalAbonos(numeroDelaOt,idOt){
  numeroDelaOtGlobal = numeroDelaOt;
  idOtGlobal = idOt;



  $.ajax({
               
               headers: {
                   'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
               },
               type: 'POST',
               url: "{{ route('ordendetrabajo.abonos') }}",
               data: {
                   'numerodelaot': numeroDelaOt,
                   'idOt': idOt,

                  
               },
               success: function(data) {
               $('#modalHistorialAbonos').show();
               $('#table_historia_abonos').empty();

                   console.log("datadatadata");
                   console.log(data);
                   var totalabonos = 0;
                 $.each(data.pagos, function(index, objeto) {




                        var tr = "<tr>";
                //          // tr += "<td>" + objeto.id + "</td>";
                        tr += "<td>" + (formatearFecha(objeto.fecha) || '') + "</td>";
                        tr += "<td>" + (objeto.descripcion.toUpperCase() || '') + "</td>";
                        tr += "<td>" + "$"+(format_js(objeto.total) || '') + "</td>";

                  
                        
                        tr += "</tr>";

                        totalabonos = totalabonos+ objeto.total;

                         $('#table_historia_abonos').append(tr);



                        });
                        var trt = "<tr>";
                          trt += "<td></td>";
                          trt += "<td></td>";
                          trt += "<td >" + "$"+(format_js(totalabonos) || '') + "</td>";
                          trt += "</tr>";
                        $('#table_historia_abonos').append(trt);

                        $("#ltotaladeudado").css("display", "inline").text("Total adeudado: $"+format_js(data.adeudado));
                        totalAdeudadoGlobal  = data.adeudado;

               },
               error: function(xhr, status) {
                   alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
               }
           });

  

}
  function abrirModal(numeroDelaOt){
    $.ajax({
               
                    headers: {
                        'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
                    },
                    type: 'POST',
                    url: "{{ route('ordendetrabajo.historial') }}",
                    data: {
                        'numerodelaot': numeroDelaOt,
                       
                    },
                    success: function(data) {
                    $("#tabla_servicios_selecionados").empty();
                       $('#modalHistorial').show();
                        console.log(data);
                      $.each(data, function(index, objeto) {

                        var reversedIndex = data.length - index;



                            var tr = "<tr>";
                            tr += "<td>" + reversedIndex+"</td>";

                              // tr += "<td>" + objeto.id + "</td>";
                            tr += "<td>" + (formatearFecha(objeto.fecha_ingreso_actualizacion) || '').toUpperCase() + "</td>";
                       
                             tr += "<td>" + '<a style="cursor:pointer"  onclick="irOt(' + objeto.id + ')"  >' + "REVISAR" + "</a>" +
                                "</td>";
                                // Agrega el enlace con la URL
                                tr += '<td><a href="' + '{{ route('imprimirot', ['idOT' => '']) }}' + objeto.id + '" target="_blank">' +
                                      '<span class="material-symbols-outlined">print</span>' +
                                      '</a></td>';

                            
                            $('#tabla_servicios_selecionados').append(tr);

                            });
                    },
                    error: function(xhr, status) {
                        alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
                    }
                });


  }
  function irOt(idOt){

    var baseUrl = window.location.origin; // Obtiene la URL base actual
var url = baseUrl + "/ordendetrabajo/showhistorial/" + idOt; // Combina la URL base con la ruta específica

window.location.href = url; // Redirige a la URL completa
  }
  function cerrarModal(){
    $('#modalHistorial').hide();

  }
  function cerrarModalAbonos(){
    $('#modalHistorialAbonos').hide();
  }



  $(document).ready(function() {
      permitirSoloNumeros("#montoparaabonar");



      $('#buscarData').on('keyup', function() {
          var valorIngresado = $(this).val();
        




          $.ajax({

          headers: {
              'X-CSRF-TOKEN': $('meta[name="csrf-token"]').attr('content')
          },
          type: 'POST',
          url: "{{ route('search.ot') }}",
          data: {
              'data': valorIngresado,
           
          },
          success: function(response) {
             console.log("datasssssdf");
             console.log(response.data);




          $('#tableOt').empty();
          $('#tableOtGeneral').css("display","none");
          if (valorIngresado != "") {
          
            table="";
              $(response.data).each(function(i, v) {
                  
                      
                  table+= '<tr><td>'  + v.numero_ot  + '</td>'
                  // table+= "'<tr><td> {{\App\Models\User::tipoUsuario()}} </td>'"

                    

                    +"@if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria")"
                    
                        +"@if(\App\Models\User::tipoUsuario() != 'secretaria' )"

                           +'<td>'+v.nombre_sucursal+'</td>'  
                        +"@endif"

                      +'<td>'+v.razon_social+'</td>'  
                      +'<td>'+v.rut+'</td>'  
                      +'<td>'+
                        (v.marca ? v.marca : '') + " "+
                      (v.modelo ? v.modelo : '') + " "+
                      (v.motor ? v.motor : '') + " "+
                      (v.ano ? v.ano : '') + " "+
                      (v.nombre_combustible ? v.nombre_combustible : '') 
                        +'</td>'  

                      +'<td>'+v.nombre_completo+'</td>'  
                      +'<td>'+"$"+format_js(v.total_con_descuentos) +'</td>'  



                      +"@endif"

                      +"@if(\App\Models\User::tipoUsuario() == 'operario' )"
                      +"<td class='td-val'>"+v.marca+"</td>"  
                      +"<td class='td-val'>"+v.modelo+"</td>"  
                      +"<td class='td-val'>"+v.motor+"</td>"  
                      +"<td class='td-val'>"+v.ano+"</td>"  
                      +"<td class='td-val'>"+v.nombre_combustible+"</td>"  

                    
                      +"@endif"
                      


                      // +"@if(\App\Models\User::tipoUsuario() == 'operario' )"
                      // +"<td class='td-val'>{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id ?? '')[0]->marca ?? ''}}</td>"  
                      // +"<td class='td-val'>{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id ?? '')[0]->modelo ?? ''}}</td>" 
                      // +"<td class='td-val'>{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id  ?? '')[0]->motor ?? ''}}</td>"  
                      // +"<td class='td-val'>{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id  ?? '')[0]->ano ?? ''}}</td>"
                      // +"<td class='td-val'>{{\App\Models\ordenes_trabajos::datosdelequipo($los_datos->id  ?? '')[0]->nombrecombustible ?? ''}}</td>"

                      // +"@endif"
                      


                      +'<td>'+formatearFecha(v.fecha_ingreso)+'</td>'  
                      +'<td>'+formatearFecha(v.fecha_entrega)+'</td>'  
                      +'<td>'+v.descripcionestado+'</td>'  


                      // +'<td>'+v.correo+'</td>'  
                      // +'<td>'+v.nombre_direccion+'</td>'  
                      // +'<td>'+v.des_region+'</td>'  
                      // +'<td>'+v.des_comuna+'</td>'  

                      +'<td>';

                    if(v.descripcionestado == "FACTURADA" || v.descripcionestado == "CANCELADA" ){

                      table+="@if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "superadmin")";

                  
                      table+= '<a href="{{ route('ordendetrabajo.showhistorial',['id' => ''])}}' + "/"+v.id + '" style="cursor: pointer">'                        
                    +'<span class="material-symbols-outlined">visibility</span></a>'; 
                      table+="@endif";

                    }else{

                      
                      table += '<a href="{{ route('ordendetrabajo.show', ['id' => '']) }}' + "/"+v.id + '" style="cursor: pointer">'                        
       + '<span class="material-symbols-outlined">visibility</span></a>';

                    }




                    table+="@if(\App\Models\User::tipoUsuario() == "superadmin" || \App\Models\User::tipoUsuario() == "admin" || \App\Models\User::tipoUsuario() == "secretaria")";
                      // table += '<a><span class="material-symbols-outlined">delete</span></a>';

                    if(v.descripcionestado == "FACTURADA" || v.descripcionestado == "CANCELADA" ){
                     }else{

                      table += '<a href="{{ route('ordendetrabajo.editar', ['id' => '']) }}' + "/"+v.id + '" style="cursor: pointer">'                        
                      + '<span class="material-symbols-outlined">edit</span></a>';
                    }

                      // table += '<span class="material-symbols-outlined" style="cursor:pointer"  onclick="abrirModal({{$los_datos->numero_ot ?? ''}})" >manage_search</span>';
                      table += '<span class="material-symbols-outlined" style="cursor:pointer" onclick="abrirModal(' + v.numero_ot + ')" >manage_search</span>';

                      // table += '<span class="material-symbols-outlined" style="cursor:pointer" onclick="abrirModalAbonos({{$los_datos->numero_ot ?? ''}},{{$los_datos->id ?? ''}})">paid</span>';
                      // table += '<span class="material-symbols-outlined" style="cursor:pointer" onclick="abrirModalAbonos({{$los_datos->numero_ot ?? ''}},' +v.id + ')">paid</span>';
                      table += '<span class="material-symbols-outlined" style="cursor:pointer" onclick="abrirModalAbonos(' + v.numero_ot + ',' + v.id + ')">paid</span>';
                      
                      +'</td></tr>';
                      table+="@endif";
                      
              })
              $('#tableOt').append( table );
          } else {
          $("#tableOtGeneral").css("display","");

              $('#tableOt').empty();

          }


          },
          error: function(xhr, status) {
              alert('Disculpe, Ha ocurrido un problema, Intente mas tarde');
          }
          });



         
     

      });



        });

        //ABRIR OTRA URL
        $(document).ready(function() {
    // Verificar si hay un mensaje en la sesión
    var mensaje = '{{ session("mensaje") }}';
    if (mensaje !== '') {
      //  alert(mensaje); // Mostrar el mensaje flash

        // Verificar si hay un ID de orden de trabajo en la sesión
        var idOT = '{{ session("idOT") }}';
        if (idOT !== '') {

          // alert(idOT);
            // Construir la URL para la nueva pestaña
            // http://35.232.42.155:8500/imprimir/ot?idOT=%3AidOT
            var url = '{{ route("imprimirot", ["idOT" => "laot"]) }}';
            url = url.replace('laot', idOT);

            // Abrir una nueva pestaña con la URL
            window.open(url, '_blank');
        }
    }
});
function validarDiferenciaAno(fechaInicioId, fechaFinId) {
  // Obtener los valores de los inputs
  var fecha_inicio = new Date($(fechaInicioId).val());
  var fecha_fin = new Date($(fechaFinId).val());

  // Calcular la diferencia en milisegundos
  var diferenciaMilisegundos = fecha_fin - fecha_inicio;

  // Calcular el número de milisegundos en un año
  var milisegundosEnUnAno = 365 * 24 * 60 * 60 * 1000;

  // Verificar si la diferencia es mayor a un año
  if (diferenciaMilisegundos > milisegundosEnUnAno) {
    // Si es mayor a un año, aplicar estilo rojo al input de fecha fin
    $(fechaFinId).css("color", "red");

    $("#textoerror").text("Rango superior a un año calendario, favor de ingresar fechas nuevamente");
    
    return true; // Indicar que la diferencia es mayor a un año
  } else {
    // Si no es mayor a un año, asegurarse de que el estilo rojo se elimine
    $("#textoerror").text("");

    $(fechaFinId).css("color", "");
    return false; // Indicar que la diferencia no es mayor a un año
  }
}
</script>

<script>
  $(function () {
      $('input[name="customDateRange"]').daterangepicker({
          opens: 'left',
          locale: {
              format: 'DD-MM-YYYY',
              applyLabel: 'Aplicar',
              cancelLabel: 'Cancelar',
              fromLabel: 'Desde',
              toLabel: 'Hasta',
              customRangeLabel: 'Personalizado',
              daysOfWeek: ['Do', 'Lu', 'Ma', 'Mi', 'Ju', 'Vi', 'Sa'],
              monthNames: ['Enero', 'Febrero', 'Marzo', 'Abril', 'Mayo', 'Junio', 'Julio',
                  'Agosto', 'Septiembre', 'Octubre', 'Noviembre', 'Diciembre'
              ],
              firstDay: 1
          },
          ranges: {
              'Hoy': [moment(), moment()],
              'Esta Semana': [moment().startOf('isoWeek'), moment().endOf('isoWeek')],
              'Este Mes': [moment().startOf('month'), moment().endOf('month')],
              'Mes Pasado': [moment().subtract(1, 'month').startOf('month'), moment()
                  .subtract(1,
                      'month').endOf('month')
              ]
          }
      });

      // Inicializar DataTables
  });
</script>

<script>
$(document).ready(function() {

  // LLamamos la funcion cuando se inicia el sistema
  formatFecha($("#customDateRange").val());
    $('#customDateRange').on('change', function() {
        var valor = $(this).val();

        formatFecha(valor);
        // console.log('Nuevo valor del campo customDateRange:', valor);
        // Aquí puedes realizar otras acciones con el valor capturado
        
    });
});


function formatFecha(fecha){
  // Separar las fechas por el separador '-'
var partes = fecha.split(' - ');

    // Obtener las fechas separadas
    var fechaInicio = partes[0];
    var fechaFin = partes[1];

    // Función para formatear la fecha en dd/mm/yyyy
    function formatearFecha(fecha) {
      var partes = fecha.split('-');
        if (partes.length === 3) {
            return partes[2] + '-' + partes[1] + '-' + partes[0];
        } else {
            return '';
        }
    }

    // Formatear las fechas
    var fechaInicioFormateada = formatearFecha(fechaInicio);
    var fechaFinFormateada = formatearFecha(fechaFin);


    $('#fecha_inicio').val(fechaInicioFormateada);
    $('#fecha_fin').val(fechaFinFormateada);
    // Mostrar los resultados
    var resultado = 'inicio= ' + fechaInicioFormateada + '<br>fin= ' + fechaFinFormateada;
        console.log(resultado);
}
</script>

@endsection
